@@ -125,6 +125,12 @@ void MainWindow::setup()
         readDefaultGrub();
     }
 
+    if (cmd.getCmdOut("df --output=fstype " + (chroot.isEmpty() ? "/boot" : tmpdir.path()) + " | tail -n1")
+        == "btrfs") {
+        ui->checkSaveDefault->setChecked(false);
+        ui->checkSaveDefault->setDisabled(true);
+    }
+
     readKernelOpts();
     ui->radioLimitedMsg->setVisible(!ui->checkBootsplash->isChecked());
     if (inVirtualMachine())
